/* vm-creator.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from vm-creator.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <stdlib.h>
#include <string.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesVMCreatorPrivate BoxesVMCreatorPrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block65Data Block65Data;
typedef struct _Block66Data Block66Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesVmCreatorCreateVmData BoxesVmCreatorCreateVmData;
typedef struct _Block67Data Block67Data;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _Block68Data Block68Data;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesVmCreatorContinueInstallationData BoxesVmCreatorContinueInstallationData;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _Block69Data Block69Data;
typedef struct _Block70Data Block70Data;
typedef struct _BoxesVmCreatorUpdateInstallProgressData BoxesVmCreatorUpdateInstallProgressData;
typedef struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData BoxesVmCreatorCreateDomainNameAndTitleFromMediaData;
typedef struct _BoxesVmCreatorCreateTargetVolumeData BoxesVmCreatorCreateTargetVolumeData;
typedef struct _BoxesVmCreatorGetStoragePoolData BoxesVmCreatorGetStoragePoolData;
typedef struct _BoxesParamSpecVMCreator BoxesParamSpecVMCreator;

struct _BoxesVMCreator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesVMCreatorPrivate * priv;
};

struct _BoxesVMCreatorClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesVMCreator *self);
};

struct _BoxesVMCreatorPrivate {
	BoxesInstallerMedia* _install_media;
	gulong state_changed_id;
	guint _num_reboots;
	gint prev_progress;
	gboolean updating_install_progress;
};

struct _Block65Data {
	int _ref_count_;
	BoxesVMCreator * self;
	gpointer _async_data_;
};

struct _Block66Data {
	int _ref_count_;
	Block65Data * _data65_;
	gulong handler;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
};

typedef enum  {
	BOXES_VM_CONFIGURATOR_ERROR_NO_GUEST_CAPS
} BoxesVMConfiguratorError;
#define BOXES_VM_CONFIGURATOR_ERROR boxes_vm_configurator_error_quark ()
struct _BoxesVmCreatorCreateVmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* result;
	Block65Data* _data65_;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	gboolean _tmp3_;
	Block66Data* _data66_;
	BoxesApp* _tmp4_;
	gulong _tmp5_;
	gchar* title;
	gchar* name;
	gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	GCancellable* _tmp10_;
	GError* _error_;
	BoxesApp* _tmp11_;
	BoxesNotificationbar* _tmp12_;
	const gchar* _tmp13_;
	GdNotification* _tmp14_;
	GdNotification* _tmp15_;
	GError* _tmp16_;
	const gchar* _tmp17_;
	GVirStorageVol* volume;
	const gchar* _tmp18_;
	BoxesInstallerMedia* _tmp19_;
	OsinfoResources* _tmp20_;
	gint64 _tmp21_;
	gint64 _tmp22_;
	GVirStorageVol* _tmp23_;
	GVirConfigCapabilities* caps;
	GVirConnection* _tmp24_;
	GVirConnection* _tmp25_;
	GVirConnection* _tmp26_;
	GCancellable* _tmp27_;
	GVirConfigCapabilities* _tmp28_;
	GVirConfigCapabilities* _tmp29_;
	const gchar* _tmp30_;
	GVirStorageVol* _tmp31_;
	const gchar* _tmp32_;
	GVirConfigDomain* config;
	BoxesInstallerMedia* _tmp33_;
	GVirConfigCapabilities* _tmp34_;
	GVirConfigDomain* _tmp35_;
	GVirConfigDomain* _tmp36_;
	const gchar* _tmp37_;
	GVirConfigDomain* _tmp38_;
	const gchar* _tmp39_;
	GVirDomain* domain;
	GVirConnection* _tmp40_;
	GVirConnection* _tmp41_;
	GVirConnection* _tmp42_;
	GVirConfigDomain* _tmp43_;
	GVirDomain* _tmp44_;
	GVirDomain* _tmp45_;
	BoxesLibvirtMachine* _tmp46_;
	BoxesLibvirtBroker* _tmp47_;
	BoxesLibvirtBroker* _tmp48_;
	BoxesApp* _tmp49_;
	BoxesCollectionSource* _tmp50_;
	BoxesCollectionSource* _tmp51_;
	BoxesApp* _tmp52_;
	GVirConnection* _tmp53_;
	GVirConnection* _tmp54_;
	GVirConnection* _tmp55_;
	GVirDomain* _tmp56_;
	BoxesLibvirtMachine* _tmp57_;
	BoxesLibvirtMachine* _tmp58_;
	GError * _inner_error_;
};

struct _Block67Data {
	int _ref_count_;
	BoxesVMCreator * self;
	BoxesLibvirtMachine* machine;
};

struct _Block68Data {
	int _ref_count_;
	Block67Data * _data67_;
	gulong signal_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesVmCreatorContinueInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	BoxesMediaManager* _tmp0_;
	BoxesMediaManager* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirConfigDomain* _tmp3_;
	GVirConfigDomain* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomain* _tmp9_;
	guint _tmp10_;
	gchar* name;
	BoxesLibvirtMachine* _tmp11_;
	GVirDomain* _tmp12_;
	GVirDomain* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesLibvirtMachine* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	const gchar* _tmp22_;
	BoxesLibvirtMachine* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesApp* _tmp26_;
	BoxesLibvirtMachine* _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	const gchar* _tmp29_;
	BoxesLibvirtMachine* _tmp30_;
	gulong _tmp31_;
	BoxesLibvirtMachine* _tmp32_;
	BoxesLibvirtMachine* _tmp33_;
	BoxesLibvirtMachine* _tmp34_;
	gboolean _tmp35_;
	BoxesLibvirtMachine* _tmp36_;
	BoxesMachineMachineState _tmp37_;
	BoxesMachineMachineState _tmp38_;
	BoxesLibvirtMachine* _tmp39_;
	GVirConfigDomain* _tmp40_;
	GVirConfigDomain* _tmp41_;
	gboolean _tmp42_;
	gboolean _tmp43_;
	BoxesLibvirtMachine* _tmp44_;
	GVirDomain* _tmp45_;
	GVirDomain* _tmp46_;
	GError* e;
	BoxesLibvirtMachine* _tmp47_;
	const gchar* _tmp48_;
	const gchar* _tmp49_;
	GError* _tmp50_;
	const gchar* _tmp51_;
	GError * _inner_error_;
};

struct _Block69Data {
	int _ref_count_;
	BoxesVMCreator * self;
	BoxesLibvirtMachine* machine;
};

struct _Block70Data {
	int _ref_count_;
	BoxesVMCreator * self;
	gint progress;
	BoxesLibvirtMachine* machine;
	gpointer _async_data_;
};

struct _BoxesVmCreatorUpdateInstallProgressData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	Block70Data* _data70_;
	BoxesLibvirtMachine* _tmp0_;
	GError* _error_;
	BoxesLibvirtMachine* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVol* _tmp3_;
	const gchar* _tmp4_;
	GError* _tmp5_;
	const gchar* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	gchar* base_title;
	BoxesInstallerMedia* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	OsinfoOs* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* base_name;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp15_;
	gint i;
	gboolean _tmp16_;
	gboolean _tmp17_;
	gint _tmp18_;
	gboolean _tmp19_;
	gboolean _tmp20_;
	GVirConnection* _tmp21_;
	GVirConnection* _tmp22_;
	GVirConnection* _tmp23_;
	const gchar* _tmp24_;
	GVirDomain* _tmp25_;
	GVirDomain* _tmp26_;
	gboolean _tmp27_;
	GVirConnection* _tmp28_;
	GVirConnection* _tmp29_;
	GVirConnection* _tmp30_;
	const gchar* _tmp31_;
	GVirDomain* _tmp32_;
	GVirDomain* _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp35_;
	GVirStorageVol* _tmp36_;
	GVirStorageVol* _tmp37_;
	gboolean _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gint _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	const gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	gint _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateTargetVolumeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gint64 storage;
	GVirStorageVol* result;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp0_;
	GVirConfigStorageVol* config;
	const gchar* _tmp1_;
	gint64 _tmp2_;
	GVirConfigStorageVol* _tmp3_;
	GVirStorageVol* volume;
	GVirStoragePool* _tmp4_;
	GVirConfigStorageVol* _tmp5_;
	GVirStorageVol* _tmp6_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorGetStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GVirStoragePool* result;
	GVirStoragePool* pool;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirStoragePool* _tmp4_;
	GVirStoragePool* _tmp5_;
	GVirConfigStoragePool* config;
	GVirConfigStoragePool* _tmp6_;
	GVirStoragePool* _tmp7_;
	GVirConnection* _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	GVirConfigStoragePool* _tmp11_;
	GVirStoragePool* _tmp12_;
	GVirStoragePool* _tmp13_;
	GVirStoragePool* _tmp14_;
	GVirStoragePool* _tmp15_;
	GVirStoragePool* _tmp16_;
	GError * _inner_error_;
};

struct _BoxesParamSpecVMCreator {
	GParamSpec parent_instance;
};


static gpointer boxes_vm_creator_parent_class = NULL;
extern BoxesApp* boxes_app_app;

gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_VM_CREATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorPrivate))
enum  {
	BOXES_VM_CREATOR_DUMMY_PROPERTY
};
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
#define BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT 99
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
static void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static void boxes_vm_creator_create_vm_data_free (gpointer _data);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_);
static Block65Data* block65_data_ref (Block65Data* _data65_);
static void block65_data_unref (void * _userdata_);
static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self);
static Block66Data* block66_data_ref (Block66Data* _data66_);
static void block66_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void ___lambda101_ (Block66Data* _data66_);
static void ____lambda101__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error);
static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
GQuark boxes_vm_configurator_error_quark (void);
GVirConfigDomain* boxes_vm_configurator_create_domain_config (BoxesInstallerMedia* install_media, const gchar* target_path, GVirConfigCapabilities* caps, GError** error);
GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static Block67Data* block67_data_ref (Block67Data* _data67_);
static void block67_data_unref (void * _userdata_);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_installer_get_express_install (BoxesUnattendedInstaller* self);
static Block68Data* block68_data_ref (Block68Data* _data68_);
static void block68_data_unref (void * _userdata_);
static void ___lambda102_ (Block68Data* _data68_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ____lambda102__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec);
static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_continue_installation_data_free (gpointer _data);
static gboolean boxes_vm_creator_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_);
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint boxes_vm_configurator_get_num_reboots (GVirConfigDomain* domain);
static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value);
static void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);
static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
void boxes_vm_configurator_post_install_setup (GVirConfigDomain* domain, BoxesInstallerMedia* install_media);
static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self);
void boxes_vm_configurator_set_num_reboots (GVirConfigDomain* domain, BoxesInstallerMedia* install_media, guint num_reboots);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static Block69Data* block69_data_ref (Block69Data* _data69_);
static void block69_data_unref (void * _userdata_);
static gboolean __lambda97_ (Block69Data* _data69_);
static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static gboolean ___lambda97__gsource_func (gpointer self);
static void boxes_vm_creator_update_install_progress_data_free (gpointer _data);
static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_);
static Block70Data* block70_data_ref (Block70Data* _data70_);
static void block70_data_unref (void * _userdata_);
static void ___lambda98_ (Block70Data* _data70_, GError** error);
static void ____lambda98__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint64 boxes_installer_media_get_installed_size (BoxesInstallerMedia* self);
static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_);
static void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_create_target_volume_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_);
static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigStorageVol* boxes_vm_configurator_create_volume_config (const gchar* name, gint64 storage, GError** error);
static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data);
static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirConfigStoragePool* boxes_vm_configurator_get_pool_config (GError** error);
static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_finalize (BoxesVMCreator* obj);


BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media) {
	BoxesVMCreator* self = NULL;
	BoxesInstallerMedia* _tmp0_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (install_media != NULL, NULL);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = install_media;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (self, _tmp0_);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 998 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media) {
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct (BOXES_TYPE_VM_CREATOR, install_media);
#line 1005 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesVMCreator* self = NULL;
	BoxesLibvirtMachine* _tmp0_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation (self, _tmp0_, NULL, NULL);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 1022 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine) {
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct_for_install_completion (BOXES_TYPE_VM_CREATOR, machine);
#line 1029 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_data_free (gpointer _data) {
	BoxesVmCreatorCreateVmData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateVmData, _data_);
#line 1044 "vm-creator.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 1051 "vm-creator.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? g_object_ref (self) : NULL;
#line 1058 "vm-creator.c"
}


void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
	BoxesVMCreator* _tmp0_;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateVmData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_vm);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_vm_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1087 "vm-creator.c"
}


BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesVmCreatorCreateVmData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 1098 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 1108 "vm-creator.c"
}


static Block65Data* block65_data_ref (Block65Data* _data65_) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data65_->_ref_count_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data65_;
#line 1117 "vm-creator.c"
}


static void block65_data_unref (void * _userdata_) {
	Block65Data* _data65_;
	_data65_ = (Block65Data*) _userdata_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data65_->_ref_count_)) {
#line 1126 "vm-creator.c"
		BoxesVMCreator * self;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data65_->self;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block65Data, _data65_);
#line 1134 "vm-creator.c"
	}
}


static Block66Data* block66_data_ref (Block66Data* _data66_) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data66_->_ref_count_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data66_;
#line 1144 "vm-creator.c"
}


static void block66_data_unref (void * _userdata_) {
	Block66Data* _data66_;
	_data66_ = (Block66Data*) _userdata_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data66_->_ref_count_)) {
#line 1153 "vm-creator.c"
		BoxesVMCreator * self;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data66_->_data65_->self;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data66_->_data65_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data66_->_data65_ = NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block66Data, _data66_);
#line 1163 "vm-creator.c"
	}
}


static void ___lambda101_ (Block66Data* _data66_) {
	Block65Data* _data65_;
	BoxesVMCreator * self;
	BoxesApp* _tmp0_;
	gulong _tmp1_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_ = _data66_->_data65_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data65_->self;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data65_->_async_data_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data66_->handler;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 1185 "vm-creator.c"
}


static void ____lambda101__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda101_ (self);
#line 1192 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1206 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 1215 "vm-creator.c"
		goto _state_0;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 1219 "vm-creator.c"
		goto _state_1;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 1223 "vm-creator.c"
		goto _state_2;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 1227 "vm-creator.c"
		goto _state_3;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 1231 "vm-creator.c"
		goto _state_4;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 1235 "vm-creator.c"
		goto _state_5;
		default:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 1240 "vm-creator.c"
	}
	_state_0:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_ = g_slice_new0 (Block65Data);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_->_ref_count_ = 1;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_->self = boxes_vm_creator_ref (_data_->self);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_->_async_data_ = _data_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->_tmp2_ == NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp3_) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_ = g_slice_new0 (Block66Data);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_->_ref_count_ = 1;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_->_data65_ = block65_data_ref (_data_->_data65_);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_->handler = (gulong) 0;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_app_app;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = 0UL;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = g_signal_connect_data ((GObject*) _data_->_tmp4_, "notify::default-connection", (GCallback) ____lambda101__g_object_notify, block66_data_ref (_data_->_data66_), (GClosureNotify) block66_data_unref, 0);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_->handler = _data_->_tmp5_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1283 "vm-creator.c"
		_state_1:
		;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block66_data_unref (_data_->_data66_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_ = NULL;
#line 1290 "vm-creator.c"
	}
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 2;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media (_data_->self, boxes_vm_creator_create_vm_ready, _data_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1302 "vm-creator.c"
	_state_2:
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_finish (_data_->self, _data_->_res_, &_data_->_tmp6_, &_data_->_tmp7_, &_data_->_inner_error_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp6_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp7_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1332 "vm-creator.c"
		} else {
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1336 "vm-creator.c"
		}
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1342 "vm-creator.c"
	}
	{
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->name;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->cancellable;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation (_data_->_tmp8_, _data_->_tmp9_, _data_->_tmp10_, boxes_vm_creator_create_vm_ready, _data_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1357 "vm-creator.c"
		_state_3:
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1363 "vm-creator.c"
			goto __catch90_g_error;
		}
	}
	goto __finally90;
	__catch90_g_error:
	{
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = boxes_app_app;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = _data_->_tmp11_->notificationbar;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = _ ("An error occurred during installation preparation. Express Install dis" \
"abled.");
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = boxes_notificationbar_display_error (_data_->_tmp12_, _data_->_tmp13_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp15_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = _data_->_error_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->_tmp16_->message;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:49: Disabling unattended installation: %s", _data_->_tmp17_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 1398 "vm-creator.c"
	}
	__finally90:
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1419 "vm-creator.c"
		} else {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1423 "vm-creator.c"
		}
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1429 "vm-creator.c"
	}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->name;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->self->priv->_install_media;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = _data_->_tmp19_->resources;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = osinfo_resources_get_storage (_data_->_tmp20_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 4;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume (_data_->self, _data_->_tmp18_, _data_->_tmp22_, boxes_vm_creator_create_vm_ready, _data_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1447 "vm-creator.c"
	_state_4:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = boxes_vm_creator_create_target_volume_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp23_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1473 "vm-creator.c"
		} else {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1477 "vm-creator.c"
		}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1483 "vm-creator.c"
	}
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = boxes_vm_creator_get_connection (_data_->self);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = _data_->cancellable;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 5;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_connection_get_capabilities_async (_data_->_tmp26_, _data_->_tmp27_, boxes_vm_creator_create_vm_ready, _data_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1499 "vm-creator.c"
	_state_5:
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = gvir_connection_get_capabilities_finish (_data_->_tmp26_, _data_->_res_, &_data_->_inner_error_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp26_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->caps = _data_->_tmp29_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1531 "vm-creator.c"
		} else {
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1535 "vm-creator.c"
		}
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1541 "vm-creator.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = _data_->volume;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = gvir_storage_vol_get_path (_data_->_tmp31_, &_data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->_tmp32_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1573 "vm-creator.c"
		} else {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1577 "vm-creator.c"
		}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1583 "vm-creator.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->self->priv->_install_media;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->caps;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = boxes_vm_configurator_create_domain_config (_data_->_tmp33_, _data_->_tmp30_, _data_->_tmp34_, &_data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp35_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1617 "vm-creator.c"
		} else {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1621 "vm-creator.c"
		}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1627 "vm-creator.c"
	}
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->config;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = _data_->name;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_name (_data_->_tmp36_, _data_->_tmp37_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->config;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = _data_->title;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_title (_data_->_tmp38_, _data_->_tmp39_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = boxes_vm_creator_get_connection (_data_->self);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = _data_->_tmp40_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = _data_->_tmp41_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = _data_->config;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = gvir_connection_create_domain (_data_->_tmp42_, _data_->_tmp43_, &_data_->_inner_error_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp42_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->domain = _data_->_tmp45_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1683 "vm-creator.c"
		} else {
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1687 "vm-creator.c"
		}
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1693 "vm-creator.c"
	}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = boxes_libvirt_broker_get_default ();
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp48_ = _data_->_tmp47_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp49_ = boxes_app_app;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp50_ = boxes_app_get_default_source (_data_->_tmp49_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp51_ = _data_->_tmp50_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp52_ = boxes_app_app;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp53_ = boxes_app_get_default_connection (_data_->_tmp52_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp54_ = _data_->_tmp53_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp55_ = _data_->_tmp54_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp56_ = _data_->domain;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp57_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp57_ = boxes_libvirt_broker_add_domain (_data_->_tmp48_, _data_->_tmp51_, _data_->_tmp55_, _data_->_tmp56_, &_data_->_inner_error_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp58_ = _data_->_tmp57_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp55_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp48_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp46_ = _data_->_tmp58_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->domain);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data_->_data65_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data65_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1755 "vm-creator.c"
		} else {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1759 "vm-creator.c"
		}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1765 "vm-creator.c"
	}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->_tmp46_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block65_data_unref (_data_->_data65_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1789 "vm-creator.c"
	} else {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1793 "vm-creator.c"
	}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block65_data_unref (_data_->_data65_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data65_ = NULL;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1819 "vm-creator.c"
	} else {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1823 "vm-creator.c"
	}
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1829 "vm-creator.c"
}


static Block67Data* block67_data_ref (Block67Data* _data67_) {
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data67_->_ref_count_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data67_;
#line 1838 "vm-creator.c"
}


static void block67_data_unref (void * _userdata_) {
	Block67Data* _data67_;
	_data67_ = (Block67Data*) _userdata_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data67_->_ref_count_)) {
#line 1847 "vm-creator.c"
		BoxesVMCreator * self;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data67_->self;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data67_->machine);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block67Data, _data67_);
#line 1857 "vm-creator.c"
	}
}


static Block68Data* block68_data_ref (Block68Data* _data68_) {
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data68_->_ref_count_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data68_;
#line 1867 "vm-creator.c"
}


static void block68_data_unref (void * _userdata_) {
	Block68Data* _data68_;
	_data68_ = (Block68Data*) _userdata_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data68_->_ref_count_)) {
#line 1876 "vm-creator.c"
		BoxesVMCreator * self;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data68_->_data67_->self;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block67_data_unref (_data68_->_data67_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_->_data67_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block68Data, _data68_);
#line 1886 "vm-creator.c"
	}
}


static void ___lambda102_ (Block68Data* _data68_) {
	Block67Data* _data67_;
	BoxesVMCreator * self;
	BoxesApp* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	BoxesApp* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	BoxesApp* _tmp5_;
	gulong _tmp6_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_ = _data68_->_data67_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data67_->self;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 1915 "vm-creator.c"
	}
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_app_app;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data67_->machine;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_app_select_item (_tmp3_, (BoxesCollectionItem*) _tmp4_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_app_app;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _data68_->signal_id;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return;
#line 1931 "vm-creator.c"
}


static void ____lambda102__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda102_ (self);
#line 1938 "vm-creator.c"
}


static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (self, _sender, pspec);
#line 1945 "vm-creator.c"
}


void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
	Block67Data* _data67_;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_ = FALSE;
	BoxesInstallerMedia* _tmp3_;
	gboolean _tmp7_;
	BoxesLibvirtMachine* _tmp13_;
	gulong _tmp14_ = 0UL;
	BoxesLibvirtMachine* _tmp15_;
	BoxesLibvirtMachine* _tmp16_;
	BoxesBoxConfig* _tmp17_;
	gint64 _tmp18_ = 0LL;
	BoxesLibvirtMachine* _tmp19_;
	GError * _inner_error_ = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_ = g_slice_new0 (Block67Data);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_->_ref_count_ = 1;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_->self = boxes_vm_creator_ref (self);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data67_->machine);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_->machine = _tmp1_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = TRUE;
#line 1988 "vm-creator.c"
	} else {
		BoxesInstallerMedia* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = self->priv->_install_media;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = boxes_unattended_installer_get_express_install (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp4_) : NULL);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = !_tmp6_;
#line 2001 "vm-creator.c"
	}
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _tmp2_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp7_) {
#line 2007 "vm-creator.c"
		Block68Data* _data68_;
		BoxesApp* _tmp8_;
		gulong _tmp9_ = 0UL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_ = g_slice_new0 (Block68Data);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_->_ref_count_ = 1;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_->_data67_ = block67_data_ref (_data67_);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_->signal_id = (gulong) 0;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = boxes_app_app;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_signal_connect_data ((GObject*) _tmp8_, "notify::ui-state", (GCallback) ____lambda102__g_object_notify, block68_data_ref (_data68_), (GClosureNotify) block68_data_unref, 0);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_->signal_id = _tmp9_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block68_data_unref (_data68_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data68_ = NULL;
#line 2029 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp10_;
		GVirDomain* _tmp11_;
		GVirDomain* _tmp12_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data67_->machine;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain (_tmp10_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _tmp11_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_start (_tmp12_, (guint) 0, &_inner_error_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_propagate_error (error, _inner_error_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block67_data_unref (_data67_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data67_ = NULL;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2052 "vm-creator.c"
		}
	}
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = _data67_->machine;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = g_signal_connect ((GObject*) _tmp13_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp14_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _data67_->machine;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_tmp15_, self);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = _data67_->machine;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = ((BoxesMachine*) _tmp16_)->config;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp18_ = g_get_real_time ();
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_box_config_set_access_last_time (_tmp17_, _tmp18_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp19_ = _data67_->machine;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (self, _tmp19_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block67_data_unref (_data67_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data67_ = NULL;
#line 2081 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_data_free (gpointer _data) {
	BoxesVmCreatorContinueInstallationData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorContinueInstallationData, _data_);
#line 2094 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
	BoxesVMCreator* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorContinueInstallationData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_continue_installation);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_continue_installation_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation_co (_data_);
#line 2123 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2131 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation_co (_data_);
#line 2145 "vm-creator.c"
}


static gboolean boxes_vm_creator_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2154 "vm-creator.c"
		goto _state_0;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2158 "vm-creator.c"
		goto _state_1;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 2162 "vm-creator.c"
		goto _state_2;
		default:
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2167 "vm-creator.c"
	}
	_state_0:
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_media_manager_get_instance ();
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->machine;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp2_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_media_manager_create_installer_media_from_config (_data_->_tmp1_, _data_->_tmp4_, boxes_vm_creator_continue_installation_ready, _data_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2188 "vm-creator.c"
	_state_1:
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = boxes_media_manager_create_installer_media_from_config_finish (_data_->_tmp1_, _data_->_res_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (_data_->self, _data_->_tmp6_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp1_);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->machine;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp7_);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = 0U;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = boxes_vm_configurator_get_num_reboots (_data_->_tmp9_);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (_data_->self, _data_->_tmp10_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->machine;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = boxes_libvirt_machine_get_domain (_data_->_tmp11_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = gvir_domain_get_name (_data_->_tmp13_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp15_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = _data_->self->priv->_install_media;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp16_ == NULL) {
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:91: Could not find needed install media to continue in" \
"stallation, give up on automatic installation");
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->machine;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (_data_->self, _data_->_tmp17_);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2244 "vm-creator.c"
		} else {
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2248 "vm-creator.c"
		}
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2254 "vm-creator.c"
	}
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->self->priv->_install_media;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->_tmp18_->device_file;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = FALSE;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_EXISTS);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_data_->_tmp20_) {
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->self->priv->_install_media;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_->device_file;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->machine;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp23_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:97: Source installer media '%s' no longer exists. Dele" \
"ting machine '%s'..", _data_->_tmp22_, _data_->_tmp25_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = boxes_app_app;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = _data_->machine;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_app_delete_machine (_data_->_tmp26_, (BoxesMachine*) _data_->_tmp27_, TRUE);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2290 "vm-creator.c"
		} else {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2294 "vm-creator.c"
		}
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2300 "vm-creator.c"
	}
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->self->priv->_install_media;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->name;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_to_continue_installation (_data_->_tmp28_, _data_->_tmp29_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->machine;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = 0UL;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = g_signal_connect ((GObject*) _data_->_tmp30_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, _data_->self);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->state_changed_id = _data_->_tmp31_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->machine;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp32_, _data_->self);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->machine;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (_data_->self, _data_->_tmp33_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->machine;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (_data_->self, (GObject*) _data_->_tmp34_, NULL);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->machine;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp36_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp38_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = _data_->machine;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp39_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = FALSE;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = boxes_vm_configurator_is_install_config (_data_->_tmp41_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = _data_->_tmp42_;
#line 2348 "vm-creator.c"
	} else {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = FALSE;
#line 2352 "vm-creator.c"
	}
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = _data_->_tmp35_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp43_) {
#line 2358 "vm-creator.c"
		{
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = _data_->machine;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = boxes_libvirt_machine_get_domain (_data_->_tmp44_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = _data_->_tmp45_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 2;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_async (_data_->_tmp46_, (guint) 0, NULL, boxes_vm_creator_continue_installation_ready, _data_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2372 "vm-creator.c"
			_state_2:
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_finish (_data_->_tmp46_, _data_->_res_, &_data_->_inner_error_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_inner_error_ != NULL) {
#line 2378 "vm-creator.c"
				goto __catch91_g_error;
			}
		}
		goto __finally91;
		__catch91_g_error:
		{
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->e = _data_->_inner_error_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_inner_error_ = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = _data_->machine;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp47_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = _data_->_tmp48_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp50_ = _data_->e;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp51_ = _data_->_tmp50_->message;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:116: Failed to start '%s': %s", _data_->_tmp49_, _data_->_tmp51_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_data_->e);
#line 2403 "vm-creator.c"
		}
		__finally91:
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->name);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_data_->_inner_error_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2416 "vm-creator.c"
		}
	}
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2425 "vm-creator.c"
	} else {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2429 "vm-creator.c"
	}
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2435 "vm-creator.c"
}


static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec) {
	BoxesLibvirtMachine* machine = NULL;
	GObject* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	gboolean _tmp3_ = FALSE;
	GVirDomain* domain = NULL;
	BoxesLibvirtMachine* _tmp4_;
	GVirDomain* _tmp5_;
	GVirDomain* _tmp6_;
	GVirDomain* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	gboolean _tmp9_;
	BoxesLibvirtMachine* _tmp15_;
	BoxesMachineMachineState _tmp16_;
	BoxesMachineMachineState _tmp17_;
	BoxesLibvirtMachine* _tmp18_;
	BoxesMachineMachineState _tmp19_;
	BoxesMachineMachineState _tmp20_;
	BoxesLibvirtMachine* _tmp24_;
	BoxesLibvirtMachine* _tmp25_;
	gboolean _tmp26_ = FALSE;
	GError * _inner_error_ = NULL;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (object != NULL);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = object;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	machine = _tmp1_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = machine;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_machine_is_on ((BoxesMachine*) _tmp2_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2482 "vm-creator.c"
	}
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = machine;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_libvirt_machine_get_domain (_tmp4_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _tmp5_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	domain = _tmp7_;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = machine;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp9_ = ((BoxesMachine*) _tmp8_)->deleted;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp9_) {
#line 2500 "vm-creator.c"
		BoxesLibvirtMachine* _tmp10_;
		gulong _tmp11_;
		BoxesLibvirtMachine* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = machine;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = self->priv->state_changed_id;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:130: '%s' was deleted, no need for post-installation s" \
"etup on it", _tmp14_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2526 "vm-creator.c"
	}
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = machine;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = boxes_machine_get_state ((BoxesMachine*) _tmp15_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = _tmp16_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp17_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED) {
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2542 "vm-creator.c"
	}
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp18_ = machine;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp19_ = boxes_machine_get_state ((BoxesMachine*) _tmp18_);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp20_ = _tmp19_;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp20_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 2552 "vm-creator.c"
		BoxesLibvirtMachine* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp21_ = machine;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp22_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp21_);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp23_ = _tmp22_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:140: '%s' has saved state, no need for post-installati" \
"on setup on it", _tmp23_);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2570 "vm-creator.c"
	}
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp24_ = machine;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_increment_num_reboots (self, _tmp24_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp25_ = machine;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp26_ = boxes_vm_creator_guest_installed_os (self, _tmp25_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp26_) {
#line 2582 "vm-creator.c"
		BoxesLibvirtMachine* _tmp27_;
		BoxesInstallerMedia* _tmp28_;
		BoxesLibvirtMachine* _tmp34_;
		gulong _tmp35_;
		gboolean _tmp36_ = FALSE;
		BoxesLibvirtMachine* _tmp37_;
		GVirConfigDomain* _tmp38_;
		GVirConfigDomain* _tmp39_;
		gboolean _tmp40_ = FALSE;
		gboolean _tmp42_;
		BoxesLibvirtMachine* _tmp44_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = machine;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (self, _tmp27_);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp28_ = self->priv->_install_media;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp28_);
#line 2602 "vm-creator.c"
		{
			GVirDomain* _tmp29_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = domain;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start (_tmp29_, (guint) 0, &_inner_error_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_inner_error_ != NULL) {
#line 2611 "vm-creator.c"
				goto __catch92_g_error;
			}
		}
		goto __finally92;
		__catch92_g_error:
		{
			GError* _error_ = NULL;
			GVirDomain* _tmp30_;
			const gchar* _tmp31_ = NULL;
			GError* _tmp32_;
			const gchar* _tmp33_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_error_ = _inner_error_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_inner_error_ = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = domain;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp31_ = gvir_domain_get_name (_tmp30_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp32_ = _error_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp33_ = _tmp32_->message;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:153: Failed to start domain '%s': %s", _tmp31_, _tmp33_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_error_);
#line 2639 "vm-creator.c"
		}
		__finally92:
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (machine);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_inner_error_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2654 "vm-creator.c"
		}
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp34_ = machine;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp35_ = self->priv->state_changed_id;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp34_, _tmp35_);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp37_ = machine;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp38_ = boxes_libvirt_machine_get_domain_config (_tmp37_);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp39_ = _tmp38_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp40_ = boxes_vm_configurator_is_live_config (_tmp39_);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp40_) {
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp36_ = TRUE;
#line 2674 "vm-creator.c"
		} else {
			gboolean _tmp41_ = FALSE;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp41_ = boxes_vm_creator_install_trackable (self);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp36_ = !_tmp41_;
#line 2681 "vm-creator.c"
		}
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp42_ = _tmp36_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp42_) {
#line 2687 "vm-creator.c"
			BoxesLibvirtMachine* _tmp43_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp43_ = machine;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_machine_set_info ((BoxesMachine*) _tmp43_, NULL);
#line 2693 "vm-creator.c"
		}
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp44_ = machine;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_libvirt_machine_set_vm_creator (_tmp44_, NULL);
#line 2699 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp45_;
		GVirConfigDomain* _tmp46_;
		GVirConfigDomain* _tmp47_;
		gboolean _tmp48_ = FALSE;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp45_ = machine;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp46_ = boxes_libvirt_machine_get_domain_config (_tmp45_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp47_ = _tmp46_;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp48_ = boxes_vm_configurator_is_live_config (_tmp47_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp48_) {
#line 2715 "vm-creator.c"
			BoxesLibvirtMachine* _tmp49_;
			gulong _tmp50_;
			BoxesInstallerMedia* _tmp51_;
			BoxesApp* _tmp52_;
			BoxesLibvirtMachine* _tmp53_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp49_ = machine;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp50_ = self->priv->state_changed_id;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_signal_handler_disconnect ((GObject*) _tmp49_, _tmp50_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp51_ = self->priv->_install_media;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_installer_media_clean_up (_tmp51_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp52_ = boxes_app_app;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp53_ = machine;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_app_delete_machine (_tmp52_, (BoxesMachine*) _tmp53_, TRUE);
#line 2737 "vm-creator.c"
		} else {
			{
				GVirDomain* _tmp54_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp54_ = domain;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				gvir_domain_start (_tmp54_, (guint) 0, &_inner_error_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_inner_error_ != NULL) {
#line 2747 "vm-creator.c"
					goto __catch93_g_error;
				}
			}
			goto __finally93;
			__catch93_g_error:
			{
				GError* _error_ = NULL;
				GVirDomain* _tmp55_;
				const gchar* _tmp56_ = NULL;
				GError* _tmp57_;
				const gchar* _tmp58_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_error_ = _inner_error_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_inner_error_ = NULL;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp55_ = domain;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp56_ = gvir_domain_get_name (_tmp55_);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp57_ = _error_;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp58_ = _tmp57_->message;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_warning ("vm-creator.vala:169: Failed to start domain '%s': %s", _tmp56_, _tmp58_);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_error_free0 (_error_);
#line 2775 "vm-creator.c"
			}
			__finally93:
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_inner_error_ != NULL) {
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (domain);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (machine);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_clear_error (&_inner_error_);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return;
#line 2790 "vm-creator.c"
			}
		}
	}
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (domain);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (machine);
#line 2798 "vm-creator.c"
}


static void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
	gboolean _tmp3_ = FALSE;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain_config (_tmp0_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_vm_configurator_is_install_config (_tmp2_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 2821 "vm-creator.c"
		BoxesLibvirtMachine* _tmp4_;
		const gchar* _tmp5_ = NULL;
		BoxesLibvirtMachine* _tmp6_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = machine;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _ ("Installing...");
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp4_, _tmp5_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = machine;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_track_install_progress (self, _tmp6_);
#line 2835 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp7_;
		const gchar* _tmp8_ = NULL;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = machine;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _ ("Live");
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp7_, _tmp8_);
#line 2845 "vm-creator.c"
	}
}


static void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:184: Setting post-installation configuration on '%s'", _tmp2_);
#line 2867 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp3_;
		GVirDomain* _tmp4_;
		GVirDomain* _tmp5_;
		GVirConfigDomain* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_;
		BoxesInstallerMedia* _tmp8_;
		BoxesLibvirtMachine* _tmp9_;
		GVirDomain* _tmp10_;
		GVirDomain* _tmp11_;
		GVirConfigDomain* _tmp12_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = machine;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_libvirt_machine_get_domain (_tmp3_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _tmp4_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = gvir_domain_get_config (_tmp5_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp6_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 2892 "vm-creator.c"
			goto __catch94_g_error;
		}
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = config;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = self->priv->_install_media;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_post_install_setup (_tmp7_, _tmp8_);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = boxes_libvirt_machine_get_domain (_tmp9_);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = config;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp11_, _tmp12_, &_inner_error_);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 2915 "vm-creator.c"
			goto __catch94_g_error;
		}
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 2920 "vm-creator.c"
	}
	goto __finally94;
	__catch94_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		GError* _tmp16_;
		const gchar* _tmp17_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = machine;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp13_);
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp14_;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _error_;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = _tmp16_->message;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:190: Failed to set post-install configuration on '%s':" \
" %s", _tmp15_, _tmp17_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 2949 "vm-creator.c"
	}
	__finally94:
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2960 "vm-creator.c"
	}
}


static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	guint _tmp0_;
	GError * _inner_error_ = NULL;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (self, _tmp0_ + 1);
#line 2976 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_;
		GVirDomain* _tmp2_;
		GVirDomain* _tmp3_;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_;
		BoxesInstallerMedia* _tmp6_;
		guint _tmp7_;
		BoxesLibvirtMachine* _tmp8_;
		GVirDomain* _tmp9_;
		GVirDomain* _tmp10_;
		GVirConfigDomain* _tmp11_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = machine;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _tmp2_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp4_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 3002 "vm-creator.c"
			goto __catch95_g_error;
		}
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = config;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = self->priv->_install_media;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = self->priv->_num_reboots;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_set_num_reboots (_tmp5_, _tmp6_, _tmp7_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = machine;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = config;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 3027 "vm-creator.c"
			goto __catch95_g_error;
		}
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 3032 "vm-creator.c"
	}
	goto __finally95;
	__catch95_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _error_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_->message;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:201: Failed to update configuration on '%s': %s", _tmp14_, _tmp16_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 3061 "vm-creator.c"
	}
	__finally95:
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3072 "vm-creator.c"
	}
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3080 "vm-creator.c"
}


static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	gboolean result = FALSE;
	GVirStorageVol* volume = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirStorageVol* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVol* _tmp3_;
	GError * _inner_error_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, FALSE);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume = _tmp3_;
#line 3106 "vm-creator.c"
	{
		gboolean _tmp4_ = FALSE;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_vm_creator_install_trackable (self);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp4_) {
#line 3113 "vm-creator.c"
			gint _tmp5_ = 0;
			GVirStorageVol* _tmp6_;
			gint _tmp7_ = 0;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp6_ = volume;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp7_ = boxes_vm_creator_get_progress (self, _tmp6_, &_inner_error_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp5_ = _tmp7_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_inner_error_ != NULL) {
#line 3125 "vm-creator.c"
				goto __catch96_g_error;
			}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			result = _tmp5_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return result;
#line 3134 "vm-creator.c"
		} else {
			gboolean _tmp8_ = FALSE;
			BoxesInstallerMedia* _tmp9_;
			OsinfoMedia* _tmp10_;
			gboolean _tmp15_;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp9_ = self->priv->_install_media;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp10_ = _tmp9_->os_media;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp10_ != NULL) {
#line 3146 "vm-creator.c"
				BoxesLibvirtMachine* _tmp11_;
				GVirConfigDomain* _tmp12_;
				GVirConfigDomain* _tmp13_;
				gboolean _tmp14_ = FALSE;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp11_ = machine;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp12_ = boxes_libvirt_machine_get_domain_config (_tmp11_);
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp13_ = _tmp12_;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp14_ = boxes_vm_configurator_is_install_config (_tmp13_);
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = _tmp14_;
#line 3161 "vm-creator.c"
			} else {
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = FALSE;
#line 3165 "vm-creator.c"
			}
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp15_ = _tmp8_;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp15_) {
#line 3171 "vm-creator.c"
				guint _tmp16_;
				BoxesInstallerMedia* _tmp17_;
				OsinfoMedia* _tmp18_;
				gint _tmp19_ = 0;
				gint _tmp20_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp16_ = self->priv->_num_reboots;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = self->priv->_install_media;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp18_ = _tmp17_->os_media;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp18_, "installer-reboots", &_tmp19_, NULL);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp20_ = _tmp19_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp16_ == ((guint) _tmp20_);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 3193 "vm-creator.c"
			} else {
				GVirStorageVolInfo* info = NULL;
				GVirStorageVol* _tmp21_;
				GVirStorageVolInfo* _tmp22_ = NULL;
				GVirStorageVolInfo* _tmp23_;
				guint64 _tmp24_;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = volume;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = gvir_storage_vol_get_info (_tmp21_, &_inner_error_);
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				info = _tmp22_;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_inner_error_ != NULL) {
#line 3208 "vm-creator.c"
					goto __catch96_g_error;
				}
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = info;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp24_ = _tmp23_->allocation;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp24_ >= ((guint64) OSINFO_MEBIBYTES);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStorageVolInfo_free0 (info);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 3223 "vm-creator.c"
			}
		}
	}
	goto __finally96;
	__catch96_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp25_;
		const gchar* _tmp26_ = NULL;
		GError* _tmp27_;
		const gchar* _tmp28_;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = volume;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = gvir_storage_vol_get_name (_tmp25_);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = _error_;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp28_ = _tmp27_->message;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:221: Failed to get information from volume '%s': %s", _tmp26_, _tmp28_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (volume);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 3257 "vm-creator.c"
	}
	__finally96:
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (volume);
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_clear_error (&_inner_error_);
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3268 "vm-creator.c"
}


static Block69Data* block69_data_ref (Block69Data* _data69_) {
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data69_->_ref_count_);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data69_;
#line 3277 "vm-creator.c"
}


static void block69_data_unref (void * _userdata_) {
	Block69Data* _data69_;
	_data69_ = (Block69Data*) _userdata_;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data69_->_ref_count_)) {
#line 3286 "vm-creator.c"
		BoxesVMCreator * self;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data69_->self;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data69_->machine);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block69Data, _data69_);
#line 3296 "vm-creator.c"
	}
}


static gboolean __lambda97_ (Block69Data* _data69_) {
	BoxesVMCreator * self;
	gboolean result = FALSE;
	gint _tmp0_;
	gboolean _tmp2_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data69_->self;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->prev_progress;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ == 100) {
#line 3312 "vm-creator.c"
		BoxesLibvirtMachine* _tmp1_;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = _data69_->machine;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp1_, NULL);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 3322 "vm-creator.c"
	}
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = self->priv->updating_install_progress;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 3328 "vm-creator.c"
		BoxesLibvirtMachine* _tmp3_;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _data69_->machine;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_update_install_progress (self, _tmp3_, NULL, NULL);
#line 3334 "vm-creator.c"
	}
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = TRUE;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3340 "vm-creator.c"
}


static gboolean ___lambda97__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda97_ (self);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3349 "vm-creator.c"
}


static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	Block69Data* _data69_;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_ = FALSE;
	BoxesLibvirtMachine* _tmp3_;
	GVirStorageVol* _tmp4_;
	GVirStorageVol* _tmp5_;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data69_ = g_slice_new0 (Block69Data);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data69_->_ref_count_ = 1;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data69_->self = boxes_vm_creator_ref (self);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data69_->machine);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data69_->machine = _tmp1_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_vm_creator_install_trackable (self);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block69_data_unref (_data69_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data69_ = NULL;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3389 "vm-creator.c"
	}
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _data69_->machine;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_libvirt_machine_get_storage_volume (_tmp3_);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 6, ___lambda97__gsource_func, block69_data_ref (_data69_), block69_data_unref);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block69_data_unref (_data69_);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data69_ = NULL;
#line 3405 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_data_free (gpointer _data) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorUpdateInstallProgressData, _data_);
#line 3416 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	BoxesVMCreator* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorUpdateInstallProgressData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_update_install_progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_update_install_progress_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 3445 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3453 "vm-creator.c"
}


static Block70Data* block70_data_ref (Block70Data* _data70_) {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data70_->_ref_count_);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data70_;
#line 3462 "vm-creator.c"
}


static void block70_data_unref (void * _userdata_) {
	Block70Data* _data70_;
	_data70_ = (Block70Data*) _userdata_;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data70_->_ref_count_)) {
#line 3471 "vm-creator.c"
		BoxesVMCreator * self;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data70_->self;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data70_->machine);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block70Data, _data70_);
#line 3481 "vm-creator.c"
	}
}


static void ___lambda98_ (Block70Data* _data70_, GError** error) {
	BoxesVMCreator * self;
	gint _tmp0_ = 0;
	BoxesLibvirtMachine* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVol* _tmp3_;
	gint _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data70_->self;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data70_->machine;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_libvirt_machine_get_storage_volume (_tmp1_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _tmp2_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_vm_creator_get_progress (self, _tmp3_, &_inner_error_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _tmp4_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3512 "vm-creator.c"
	}
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data70_->progress = _tmp0_;
#line 3516 "vm-creator.c"
}


static void ____lambda98__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda98_ (self, error);
#line 3523 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 3537 "vm-creator.c"
}


static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_) {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3546 "vm-creator.c"
		goto _state_0;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3550 "vm-creator.c"
		goto _state_1;
		default:
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3555 "vm-creator.c"
	}
	_state_0:
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_ = g_slice_new0 (Block70Data);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_->_ref_count_ = 1;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_->self = boxes_vm_creator_ref (_data_->self);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = _data_->machine;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_data70_->machine);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_->machine = _data_->_tmp0_;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_->_async_data_ = _data_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = TRUE;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_->progress = 0;
#line 3576 "vm-creator.c"
	{
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread (____lambda98__boxes_run_in_thread_func, block70_data_ref (_data_->_data70_), block70_data_unref, NULL, boxes_vm_creator_update_install_progress_ready, _data_);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3584 "vm-creator.c"
		_state_1:
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 3590 "vm-creator.c"
			goto __catch97_g_error;
		}
	}
	goto __finally97;
	__catch97_g_error:
	{
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = _data_->_data70_->machine;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp1_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = gvir_storage_vol_get_name (_data_->_tmp3_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_error_;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:257: Failed to get information from volume '%s': %s", _data_->_tmp4_, _data_->_tmp6_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 3619 "vm-creator.c"
	}
	__finally97:
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block70_data_unref (_data_->_data70_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data70_ = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_data_->_inner_error_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3634 "vm-creator.c"
	}
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_data70_->progress < 0) {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block70_data_unref (_data_->_data70_);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data70_ = NULL;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3646 "vm-creator.c"
		} else {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3650 "vm-creator.c"
		}
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3656 "vm-creator.c"
	}
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->_data70_->machine;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = ngettext ("%d%% Installed", "%d%% Installed", (gulong) _data_->_data70_->progress);
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = g_strdup_printf (_data_->_tmp8_, _data_->_data70_->progress);
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_machine_set_info ((BoxesMachine*) _data_->_tmp7_, _data_->_tmp10_);
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->_tmp10_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->prev_progress = _data_->_data70_->progress;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = FALSE;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block70_data_unref (_data_->_data70_);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data70_ = NULL;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3686 "vm-creator.c"
	} else {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3690 "vm-creator.c"
	}
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3696 "vm-creator.c"
}


static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self) {
	gboolean result = FALSE;
	BoxesInstallerMedia* _tmp0_;
	guint64 _tmp1_;
	guint64 _tmp2_;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_installer_media_get_installed_size (_tmp0_);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_ > ((guint64) 0);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3717 "vm-creator.c"
}


static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error) {
	gint result = 0;
	GVirStorageVolInfo* volume_info = NULL;
	GVirStorageVol* _tmp0_;
	GVirStorageVolInfo* _tmp1_ = NULL;
	gint percent = 0;
	guint64 _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	guint64 _tmp4_;
	guint64 _tmp5_;
	gint _tmp6_;
	gint _tmp7_ = 0;
	gint _tmp8_;
	GError * _inner_error_ = NULL;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (volume != NULL, 0);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = volume;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = gvir_storage_vol_get_info (_tmp0_, &_inner_error_);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume_info = _tmp1_;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return 0;
#line 3751 "vm-creator.c"
	}
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = volume_info->allocation;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_installer_media_get_installed_size (_tmp3_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = (gint) ((_tmp2_ * 100) / _tmp5_);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = percent;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = CLAMP (_tmp6_, 0, BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = _tmp7_;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = percent;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp8_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT) {
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		percent = 100;
#line 3775 "vm-creator.c"
	}
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = percent;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3783 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData, _data_);
#line 3794 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	BoxesVMCreator* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_domain_name_and_title_from_media);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_domain_name_and_title_from_media_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 3813 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3823 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (name) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*name = _data_->name;
#line 3831 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 3835 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (title) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*title = _data_->title;
#line 3843 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 3847 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = NULL;
#line 3851 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 3865 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3874 "vm-creator.c"
		goto _state_0;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3878 "vm-creator.c"
		goto _state_1;
		default:
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3883 "vm-creator.c"
	}
	_state_0:
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = _data_->self->priv->_install_media;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_->label;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = g_strdup (_data_->_tmp1_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_title = _data_->_tmp2_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->base_title;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = g_strdup (_data_->_tmp3_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp4_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->self->priv->_install_media;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->_tmp6_->os;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp7_ != NULL) {
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = osinfo_product_get_short_id ((OsinfoProduct*) _data_->_tmp9_);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_tmp11_;
#line 3918 "vm-creator.c"
	} else {
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = "boxes-unknown";
#line 3922 "vm-creator.c"
	}
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->_tmp5_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_name = _data_->_tmp13_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = g_strdup (_data_->base_name);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp14_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_domain_name_and_title_from_media_ready, _data_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3942 "vm-creator.c"
	_state_1:
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp15_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_title);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3964 "vm-creator.c"
		} else {
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3968 "vm-creator.c"
		}
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3974 "vm-creator.c"
	}
	{
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->i = 2;
#line 3979 "vm-creator.c"
		{
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp16_ = TRUE;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			while (TRUE) {
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp17_) {
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp18_ = _data_->i;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->i = _data_->_tmp18_ + 1;
#line 3993 "vm-creator.c"
				}
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp16_ = FALSE;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp21_ = boxes_vm_creator_get_connection (_data_->self);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp22_ = _data_->_tmp21_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp23_ = _data_->_tmp22_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp24_ = _data_->name;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = NULL;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = gvir_connection_find_domain_by_name (_data_->_tmp23_, _data_->_tmp24_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp26_ = _data_->_tmp25_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp27_ = _data_->_tmp26_ != NULL;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp26_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp23_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp27_) {
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = TRUE;
#line 4021 "vm-creator.c"
				} else {
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp28_ = boxes_vm_creator_get_connection (_data_->self);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp29_ = _data_->_tmp28_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp30_ = _data_->_tmp29_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp31_ = _data_->title;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp32_ = NULL;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp32_ = gvir_connection_find_domain_by_name (_data_->_tmp30_, _data_->_tmp31_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp33_ = _data_->_tmp32_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = _data_->_tmp33_ != NULL;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp33_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp30_);
#line 4043 "vm-creator.c"
				}
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = _data_->_tmp20_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp34_) {
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = TRUE;
#line 4051 "vm-creator.c"
				} else {
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp35_ = _data_->name;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp36_ = NULL;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp36_ = gvir_storage_pool_get_volume (_data_->pool, _data_->_tmp35_);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp37_ = _data_->_tmp36_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = _data_->_tmp37_ != NULL;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp37_);
#line 4065 "vm-creator.c"
				}
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp38_ = _data_->_tmp19_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp38_) {
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					break;
#line 4073 "vm-creator.c"
				}
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp39_ = g_strconcat (_data_->base_name, "-", NULL);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp40_ = _data_->_tmp39_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp41_ = _data_->i;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp42_ = NULL;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp42_ = g_strdup_printf ("%i", _data_->_tmp41_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp43_ = _data_->_tmp42_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp44_ = g_strconcat (_data_->_tmp40_, _data_->_tmp43_, NULL);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->name);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->name = _data_->_tmp44_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp43_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp40_);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp45_ = _data_->base_title;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp46_ = g_strconcat (_data_->_tmp45_, " ", NULL);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp47_ = _data_->_tmp46_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp48_ = _data_->i;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp49_ = NULL;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp49_ = g_strdup_printf ("%i", _data_->_tmp48_);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp50_ = _data_->_tmp49_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp51_ = g_strconcat (_data_->_tmp47_, _data_->_tmp50_, NULL);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->title);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->title = _data_->_tmp51_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp50_);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp47_);
#line 4121 "vm-creator.c"
			}
		}
	}
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4135 "vm-creator.c"
	} else {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4139 "vm-creator.c"
	}
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4145 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_data_free (gpointer _data) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateTargetVolumeData, _data_);
#line 4160 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	BoxesVMCreator* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gint64 _tmp3_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateTargetVolumeData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_target_volume);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_target_volume_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = storage;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->storage = _tmp3_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 4194 "vm-creator.c"
}


static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStorageVol* result;
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 4205 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4215 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 4229 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_) {
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 4238 "vm-creator.c"
		goto _state_0;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 4242 "vm-creator.c"
		goto _state_1;
		default:
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 4247 "vm-creator.c"
	}
	_state_0:
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_target_volume_ready, _data_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4256 "vm-creator.c"
	_state_1:
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp0_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4274 "vm-creator.c"
		} else {
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4278 "vm-creator.c"
		}
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4284 "vm-creator.c"
	}
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->name;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->storage;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_vm_configurator_create_volume_config (_data_->_tmp1_, _data_->_tmp2_, &_data_->_inner_error_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp3_;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4308 "vm-creator.c"
		} else {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4312 "vm-creator.c"
		}
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4318 "vm-creator.c"
	}
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->pool;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->config;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = gvir_storage_pool_create_volume (_data_->_tmp4_, _data_->_tmp5_, &_data_->_inner_error_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp6_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4344 "vm-creator.c"
		} else {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4348 "vm-creator.c"
		}
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4354 "vm-creator.c"
	}
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->volume;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4366 "vm-creator.c"
	} else {
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4370 "vm-creator.c"
	}
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4386 "vm-creator.c"
	} else {
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4390 "vm-creator.c"
	}
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4396 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorGetStoragePoolData, _data_);
#line 4409 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	BoxesVMCreator* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorGetStoragePoolData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_get_storage_pool);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_get_storage_pool_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 4428 "vm-creator.c"
}


static GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStoragePool* result;
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 4439 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4449 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 4463 "vm-creator.c"
}


static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_) {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 4472 "vm-creator.c"
		goto _state_0;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 4476 "vm-creator.c"
		goto _state_1;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 4480 "vm-creator.c"
		goto _state_2;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 4484 "vm-creator.c"
		goto _state_3;
		default:
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 4489 "vm-creator.c"
	}
	_state_0:
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_get_storage_pool (_data_->_tmp2_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->pool;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp5_ == NULL) {
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = boxes_vm_configurator_get_pool_config (&_data_->_inner_error_);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->config = _data_->_tmp6_;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4530 "vm-creator.c"
			} else {
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4534 "vm-creator.c"
			}
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 4540 "vm-creator.c"
		}
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = boxes_vm_creator_get_connection (_data_->self);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->config;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = NULL;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = gvir_connection_create_storage_pool (_data_->_tmp10_, _data_->_tmp11_, (guint) 0, &_data_->_inner_error_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = _data_->_tmp13_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4574 "vm-creator.c"
			} else {
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4578 "vm-creator.c"
			}
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 4584 "vm-creator.c"
		}
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->pool = _data_->_tmp7_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = _data_->pool;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_async (_data_->_tmp14_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4598 "vm-creator.c"
		_state_1:
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4616 "vm-creator.c"
			} else {
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4620 "vm-creator.c"
			}
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 4626 "vm-creator.c"
		}
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->pool;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 2;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_async (_data_->_tmp15_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4636 "vm-creator.c"
		_state_2:
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_finish (_data_->_tmp15_, _data_->_res_, &_data_->_inner_error_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4654 "vm-creator.c"
			} else {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4658 "vm-creator.c"
			}
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 4664 "vm-creator.c"
		}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = _data_->pool;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_async (_data_->_tmp16_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4674 "vm-creator.c"
		_state_3:
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4692 "vm-creator.c"
			} else {
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4696 "vm-creator.c"
			}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 4702 "vm-creator.c"
		}
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 4706 "vm-creator.c"
	}
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->pool;
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4714 "vm-creator.c"
	} else {
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4718 "vm-creator.c"
	}
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4730 "vm-creator.c"
	} else {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4734 "vm-creator.c"
	}
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4740 "vm-creator.c"
}


BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4755 "vm-creator.c"
}


static void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_install_media = _tmp1_;
#line 4772 "vm-creator.c"
}


static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self) {
	GVirConnection* result;
	BoxesApp* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_app_get_default_connection (_tmp0_);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4793 "vm-creator.c"
}


static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self) {
	guint result;
	guint _tmp0_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4808 "vm-creator.c"
}


static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value) {
	guint _tmp0_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_num_reboots = _tmp0_;
#line 4820 "vm-creator.c"
}


static void boxes_value_vm_creator_init (GValue* value) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	value->data[0].v_pointer = NULL;
#line 4827 "vm-creator.c"
}


static void boxes_value_vm_creator_free_value (GValue* value) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (value->data[0].v_pointer) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (value->data[0].v_pointer);
#line 4836 "vm-creator.c"
	}
}


static void boxes_value_vm_creator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (src_value->data[0].v_pointer) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = boxes_vm_creator_ref (src_value->data[0].v_pointer);
#line 4846 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 4850 "vm-creator.c"
	}
}


static gpointer boxes_value_vm_creator_peek_pointer (const GValue* value) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 4858 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (collect_values[0].v_pointer) {
#line 4865 "vm-creator.c"
		BoxesVMCreator* object;
		object = collect_values[0].v_pointer;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4872 "vm-creator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4876 "vm-creator.c"
		}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = boxes_vm_creator_ref (object);
#line 4880 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4884 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 4888 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesVMCreator** object_p;
	object_p = collect_values[0].v_pointer;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!object_p) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 4899 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!value->data[0].v_pointer) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = NULL;
#line 4905 "vm-creator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = value->data[0].v_pointer;
#line 4909 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = boxes_vm_creator_ref (value->data[0].v_pointer);
#line 4913 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 4917 "vm-creator.c"
}


GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecVMCreator* spec;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return G_PARAM_SPEC (spec);
#line 4931 "vm-creator.c"
}


gpointer boxes_value_get_vm_creator (const GValue* value) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 4940 "vm-creator.c"
}


void boxes_value_set_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_ref (value->data[0].v_pointer);
#line 4960 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4964 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 4970 "vm-creator.c"
	}
}


void boxes_value_take_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 4989 "vm-creator.c"
	} else {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4993 "vm-creator.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 4999 "vm-creator.c"
	}
}


static void boxes_vm_creator_class_init (BoxesVMCreatorClass * klass) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_parent_class = g_type_class_peek_parent (klass);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->finalize = boxes_vm_creator_finalize;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_type_class_add_private (klass, sizeof (BoxesVMCreatorPrivate));
#line 5011 "vm-creator.c"
}


static void boxes_vm_creator_instance_init (BoxesVMCreator * self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv = BOXES_VM_CREATOR_GET_PRIVATE (self);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->prev_progress = 0;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->ref_count = 1;
#line 5022 "vm-creator.c"
}


static void boxes_vm_creator_finalize (BoxesVMCreator* obj) {
	BoxesVMCreator * self;
	BoxesInstallerMedia* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VM_CREATOR, BoxesVMCreator);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ != NULL) {
#line 5035 "vm-creator.c"
		BoxesInstallerMedia* _tmp1_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = self->priv->_install_media;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp1_);
#line 5041 "vm-creator.c"
	}
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 5045 "vm-creator.c"
}


GType boxes_vm_creator_get_type (void) {
	static volatile gsize boxes_vm_creator_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vm_creator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_vm_creator_init, boxes_value_vm_creator_free_value, boxes_value_vm_creator_copy_value, boxes_value_vm_creator_peek_pointer, "p", boxes_value_vm_creator_collect_value, "p", boxes_value_vm_creator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVMCreatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vm_creator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVMCreator), 0, (GInstanceInitFunc) boxes_vm_creator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_vm_creator_type_id;
		boxes_vm_creator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesVMCreator", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_vm_creator_type_id__volatile, boxes_vm_creator_type_id);
	}
	return boxes_vm_creator_type_id__volatile;
}


gpointer boxes_vm_creator_ref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return instance;
#line 5070 "vm-creator.c"
}


void boxes_vm_creator_unref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		BOXES_VM_CREATOR_GET_CLASS (self)->finalize (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 5083 "vm-creator.c"
	}
}



